// newtab.js -- Script called on new tab open

// Copyright 2013, 2014 by John K. Hinsdale.  See LICENSE.html for terms of use.

/* Try very hard to load the new tab page in a way so that it is
 * loaded AFTER the extension is installed and the extension options
 * loaded, and all extension web listeners installed.  This will more
 * reliably subject the newtab URL to filtering by the extension.  If
 * we don't do this, the new tab URL will not be subject to the
 * filtering, particularly when it is called on browser startup.  This
 * will be a problem in the case the new tab URL is a search engine
 * page to which cookies should not be sent.
 *
 * If the extension is enabled, uses the option "newtab_url" to get
 * the URL, else leaves it as the blank page (newtab.html).
 */

function try_load(ntry) {
    var b = chrome.extension.getBackgroundPage();
    if ( ntry > 15 ) {
        alert("too many tries");
        return;
    }
    if ( ! b || ! b.GLOBAL__loaded )
        setTimeout(function() { try_load(ntry + 1) }, 300);
    else {
        var opts = b.GLOBAL__options;
        if ( opts.enabled && opts.newtab_url && opts.newtab_url.length > 0 )
            window.location.replace(opts.newtab_url);
    }
}

// Call this when newtab page is loaded to redirect to the configured URL
function newtab_loaded() {
    try_load(0);
}

document.addEventListener('DOMContentLoaded', newtab_loaded);

// $Id: newtab.js,v 1.4 2014/12/23 12:38:42 hin Exp $
